aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKarel Kočí <cynerd@email.cz>2018-01-25 15:45:29 +0100
committerKarel Kočí <cynerd@email.cz>2018-01-25 15:45:29 +0100
commitdb722b7163fffc868cdea338bd6a4c6eddffd2b1 (patch)
treee617d6e3577d4f3b095cfe81bc757efb8c72cd3f
parent92c7fd220506df5f7997d27dbbcdb513e66932a7 (diff)
downloadqtmips-db722b7163fffc868cdea338bd6a4c6eddffd2b1.tar.gz
qtmips-db722b7163fffc868cdea338bd6a4c6eddffd2b1.tar.bz2
qtmips-db722b7163fffc868cdea338bd6a4c6eddffd2b1.zip
Fix compilation
-rw-r--r--qtmips_gui/programdock.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/qtmips_gui/programdock.cpp b/qtmips_gui/programdock.cpp
index 9178dce..06aa9cd 100644
--- a/qtmips_gui/programdock.cpp
+++ b/qtmips_gui/programdock.cpp
@@ -2,7 +2,7 @@
#include "qtmipsexception.h"
ProgramView::ProgramView(QWidget *parent) : MemoryView(parent) {
- set_center(0x80020000); // Initialize center address to program start
+ set_focus(0x80020000); // Initialize focus address to program start
cb_single = new QComboBox(this);
cb_single->addItems({